@@ -15,6 +15,7 @@ __WELCOME_SAYING_LABELS__ = ["sys_reply_q1", "sys_welcome"]
 __REFUSE_SAYING_LABELS__ = ["sys_reply_q2", "sys_refuse"]
 __COMPLETE_SAYING_LABELS__ = ["sys_reply_complete", "sys_complete"]
 __DISSABLE_WELCOME_LABEL__ = ["__DISSABLE_Q1__", "DISSABLE_WELCOME"]
+__DISABLE_REFUSE_LABEL__ = ["__DISABLE_REFUSE__"]
 
 from .nlp_tool import similar
 
@@ -58,6 +59,8 @@ class QAStage(Stage):
         if get_value_from_dict_by_multi_name(d=data, names=__DISSABLE_WELCOME_LABEL__, default=False):
             self.is_first_access = self.disabel_is_first_access
 
+        self.disable_refuse_question = get_value_from_dict_by_multi_name(d=data, names=__DISABLE_REFUSE_LABEL__, default=False)
+
     def __request_similar_api__(self, text, corpus):
         return similar(text, corpus)
 
@@ -101,8 +104,11 @@ class QAStage(Stage):
             pass_token = True
             kwargs = self.set_default_var(kwargs, __QA_RESPOND_THRESHOLD__, True)
         else:
-            pass_token = False
+            pass_token = False if self.disable_refuse_question is False else True
+
             kwargs = self.set_default_var(kwargs, __QA_RESPOND_THRESHOLD__, False)
+
+
         return pass_token, kwargs
 
     @staticmethod
@@ -211,8 +217,8 @@ class LibSwitchStage(Stage):
                 return stages_label
 
             #
-            assert isinstance(label, type(text)), "切換路線之條件與限定結果的類型不一致，必須保持兩者都是`str` 或是兩者都是`list`"
-            if isinstance(label, str):
+            assert not isinstance(label, list) or isinstance(label, type(text)), "切換路線之條件與限定結果的類型不一致，必須保持兩者都是`str` 或是兩者都是`list`"
+            if not isinstance(label, list):
                 label, text = [label], [text]
 
             assert len(label) == len(text), "切換路線之條件與限定結果的數量不一致"
