@@ -3,7 +3,8 @@ import uuid
 import re
 
 from .__stage__ import Stage, __USER_TEXT__, __SYS_REPLY__, StageStatus, SwitchStage, \
-    __LOCAL_VAR_LABEL__, __LOCAL_VAR_VALUE__, StageType, __PASS_TOKEN__
+    __LOCAL_VAR_LABEL__, __LOCAL_VAR_VALUE__, StageType, __PASS_TOKEN__, __KEEP_VAR__, \
+    __KEEP_DEFAULT_VAR__
 
 
 class Agent:
@@ -102,10 +103,8 @@ class MultiAgent(Agent):
                 return self.multi_stages[new_stages_label], kwargs
             else:
 
-
                 kwargs = stage.run(**kwargs)
 
-
                 if self.is_not_complete(kwargs) is True:
                     return self.get_sys_reply(kwargs), kwargs
                 else:
